@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# Copyright (C) 2015, 2016  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2015-2017  Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -14,7 +14,7 @@ use XML::Simple;
 my $ref = XMLin("xml.stats");
 my $counters = $ref->{server}->{counters};
 foreach $group (@$counters) {
-    foreach $key (keys $group->{counter}) {
+    foreach $key (keys %{$group->{counter}}) {
         print $group->{type} . " " . $key . ": ". $group->{counter}->{$key}->{content} . "\n";
     }
 }
