@@ -1,18 +1,9 @@
 /*
- * Copyright (C) 2004, 2007, 2009  Internet Systems Consortium, Inc. ("ISC")
- * Copyright (C) 1998-2001  Internet Software Consortium.
+ * Copyright (C) 1998-2001, 2004, 2007, 2009, 2015, 2016  Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
- *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
 /* $Id: mf_4.c,v 1.47 2009/12/04 22:06:37 tbox Exp $ */
@@ -30,7 +21,7 @@ fromtext_mf(ARGS_FROMTEXT) {
 	dns_name_t name;
 	isc_buffer_t buffer;
 
-	REQUIRE(type == 4);
+	REQUIRE(type == dns_rdatatype_mf);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -41,7 +32,8 @@ fromtext_mf(ARGS_FROMTEXT) {
 
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
-	origin = (origin != NULL) ? origin : dns_rootname;
+	if (origin == NULL)
+		origin = dns_rootname;
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 	return (ISC_R_SUCCESS);
 }
@@ -53,7 +45,7 @@ totext_mf(ARGS_TOTEXT) {
 	dns_name_t prefix;
 	isc_boolean_t sub;
 
-	REQUIRE(rdata->type == 4);
+	REQUIRE(rdata->type == dns_rdatatype_mf);
 	REQUIRE(rdata->length != 0);
 
 	dns_name_init(&name, NULL);
@@ -71,7 +63,7 @@ static inline isc_result_t
 fromwire_mf(ARGS_FROMWIRE) {
 	dns_name_t name;
 
-	REQUIRE(type == 4);
+	REQUIRE(type == dns_rdatatype_mf);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -88,7 +80,7 @@ towire_mf(ARGS_TOWIRE) {
 	dns_offsets_t offsets;
 	isc_region_t region;
 
-	REQUIRE(rdata->type == 4);
+	REQUIRE(rdata->type == dns_rdatatype_mf);
 	REQUIRE(rdata->length != 0);
 
 	dns_compress_setmethods(cctx, DNS_COMPRESS_GLOBAL14);
@@ -109,7 +101,7 @@ compare_mf(ARGS_COMPARE) {
 
 	REQUIRE(rdata1->type == rdata2->type);
 	REQUIRE(rdata1->rdclass == rdata2->rdclass);
-	REQUIRE(rdata1->type == 4);
+	REQUIRE(rdata1->type == dns_rdatatype_mf);
 	REQUIRE(rdata1->length != 0);
 	REQUIRE(rdata2->length != 0);
 
@@ -130,7 +122,7 @@ fromstruct_mf(ARGS_FROMSTRUCT) {
 	dns_rdata_mf_t *mf = source;
 	isc_region_t region;
 
-	REQUIRE(type == 4);
+	REQUIRE(type == dns_rdatatype_mf);
 	REQUIRE(source != NULL);
 	REQUIRE(mf->common.rdtype == type);
 	REQUIRE(mf->common.rdclass == rdclass);
@@ -148,7 +140,7 @@ tostruct_mf(ARGS_TOSTRUCT) {
 	isc_region_t r;
 	dns_name_t name;
 
-	REQUIRE(rdata->type == 4);
+	REQUIRE(rdata->type == dns_rdatatype_mf);
 	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
@@ -170,7 +162,7 @@ freestruct_mf(ARGS_FREESTRUCT) {
 	dns_rdata_mf_t *mf = source;
 
 	REQUIRE(source != NULL);
-	REQUIRE(mf->common.rdtype == 4);
+	REQUIRE(mf->common.rdtype == dns_rdatatype_mf);
 
 	if (mf->mctx == NULL)
 		return;
@@ -184,7 +176,7 @@ additionaldata_mf(ARGS_ADDLDATA) {
 	dns_offsets_t offsets;
 	isc_region_t region;
 
-	REQUIRE(rdata->type == 4);
+	REQUIRE(rdata->type == dns_rdatatype_mf);
 
 	dns_name_init(&name, offsets);
 	dns_rdata_toregion(rdata, &region);
@@ -198,7 +190,7 @@ digest_mf(ARGS_DIGEST) {
 	isc_region_t r;
 	dns_name_t name;
 
-	REQUIRE(rdata->type == 4);
+	REQUIRE(rdata->type == dns_rdatatype_mf);
 
 	dns_rdata_toregion(rdata, &r);
 	dns_name_init(&name, NULL);
@@ -210,7 +202,7 @@ digest_mf(ARGS_DIGEST) {
 static inline isc_boolean_t
 checkowner_mf(ARGS_CHECKOWNER) {
 
-	REQUIRE(type == 4);
+	REQUIRE(type == dns_rdatatype_mf);
 
 	UNUSED(name);
 	UNUSED(type);
@@ -223,7 +215,7 @@ checkowner_mf(ARGS_CHECKOWNER) {
 static inline isc_boolean_t
 checknames_mf(ARGS_CHECKNAMES) {
 
-	REQUIRE(rdata->type == 4);
+	REQUIRE(rdata->type == dns_rdatatype_mf);
 
 	UNUSED(rdata);
 	UNUSED(owner);
